@@ -1,22 +1,22 @@
 # Function to threshold network based on bootstrap samples:
 bootThreshold <- function(bootobject, alpha = 0.05,verbose=TRUE, thresholdIntercepts = FALSE){
   # Check if object is bootnet object:
-  if (class(bootobject) != "bootnet"){
+  if (!is(bootobject,"bootnet")){
     stop("'bootobject' must be an object of class 'bootnet'")
   }
-  
+
   # Check type:
   if (bootobject$type != "nonparametric" & bootobject$type != "parametric"){
     stop("Bootstrap type must be 'nonparametric' or 'parametric'")
   }
-  
+
   # Check alpha:
   if (verbose){
     exp <- expAlpha(alpha,length(bootobject$boots))
     message(paste0("Expected significance level given number of bootstrap samples is approximately: ",format(signif(exp,2),scientific = FALSE)))
   }
-  
-  
+
+
   # Extract the network object:
   Network <- bootobject$sample
   # Dummy for multiple graphs:
@@ -31,21 +31,21 @@ bootThreshold <- function(bootobject, alpha = 0.05,verbose=TRUE, thresholdInterc
     Directed <- Network$directed
     Intercepts <-  Network$intercepts
   }
-  
+
   # For every graph:
   for (g in seq_along(Graphs)){
     graphName <- names(Graphs)[g]
-    
+
     # Summary table of edge weights:
-    bootSummary <- bootobject$bootTable %>% 
-      dplyr::filter_(~type == "edge", ~graph == graphName) %>%
-      dplyr::group_by_(~node1,~node2) %>%
+    bootSummary <- bootobject$bootTable %>%
+      dplyr::filter(.data[['type']] == "edge", .data[['graph']] == graphName) %>%
+      dplyr::group_by(.data[['node1']],.data[['node2']]) %>%
       dplyr::summarize(
         lower = quantile(value, alpha/2),
         upper = quantile(value, 1 - alpha/2)
-      ) %>% 
+      ) %>%
       dplyr::mutate(sig = upper < 0 | lower > 0) %>%
-      filter_(~!sig)
+      filter(!.data[['sig']])
 
     # Threshold network:
     if (nrow(bootSummary) > 0){
@@ -58,21 +58,21 @@ bootThreshold <- function(bootobject, alpha = 0.05,verbose=TRUE, thresholdInterc
     } else {
       message("All edges indicated to be nonzero")
     }
-    
+
     # Threshold intercepts
     if (thresholdIntercepts){
-      
+
       # Summary table of edge weights:
-      bootSummary <- bootobject$bootTable %>% 
-        dplyr::filter_(~type == "intercept", ~graph == graphName) %>%
-        dplyr::group_by_(~node1) %>%
+      bootSummary <- bootobject$bootTable %>%
+        dplyr::filter(.data[['type']] == "intercept", .data[['graph']] == graphName) %>%
+        dplyr::group_by(.data[['node1']]) %>%
         dplyr::summarize(
           lower = quantile(value, alpha/2),
           upper = quantile(value, 1 - alpha/2)
-        ) %>% 
+        ) %>%
         dplyr::mutate(sig = upper < 0 | lower > 0) %>%
-        filter_(~!sig)
-      
+        filter(!.data[['sig']])
+
       # Threshold network:
       if (nrow(bootSummary) > 0){
         for (i in 1:nrow(bootSummary)){
@@ -83,7 +83,7 @@ bootThreshold <- function(bootobject, alpha = 0.05,verbose=TRUE, thresholdInterc
       }
     }
   }
-  
+
   # Return to network object:
   if (length(Graphs) == 1){
     Network$graph <- Graphs[[1]]
@@ -95,7 +95,7 @@ bootThreshold <- function(bootobject, alpha = 0.05,verbose=TRUE, thresholdInterc
 
   # Add indicator network is thresholded:
   Network$thresholded <- TRUE
-  
+
   # Return network:
   return(Network)
-}
\ No newline at end of file
+}
